# Unit 3: Physics

## Light
 - `Light`: Electromagnetic radiation/waves, as light interacts with both electricity and magnets
 - Light travels at ~**3.0*10<sup>8<\sup>**
 - `Energy`: Ability to do work
 - `Work`: Ability to move matter in space
 - Energy can be transferred and transformed, but not destroyed
 - Light behaves as a particle and/or a wave
    - Behaves as particle when travelling through a vacuum, which waves cannot do
    - Behaves as wave by forming "interference patterns", properties of light waves are also measurable
 - `Photon`: Light particle

### Properties of electromagnetic waves
<img src="https://sites.google.com/site/mrgsscienceclass/_/rsrc/1536069562258/about-science-class-1/physical-science-physics/energy-waves-1/Wave%20properties.PNG" width="500">

 - `Amplitude`: Height from centre to crest/trough
 - `Crest`: Peak of wave
 - `Trough`: Base of wave
 - `Wavelength`: Distance between two points on wave on the same plane
 - `Frequency`: Waves passing per <unit> (e.g., hertz (waves per second))
 - Visible light wavelengths are between 400-700 nm long

<img src="https://www.researchgate.net/profile/Jolanda_Patruno2/publication/280792916/figure/fig10/AS:669441209692171@1536618630777/Electromagnetic-spectrum-These-general-characteristics-above-indicated-are-valid-both.png" width="500">

 - Light always travels in a straight line
 - **Longer** wavelength = **smaller** frequency = **less** energy
 - **Shorter** wavelength = **higher** frequency = **more** energy
 - **Higher** energy, **lower** penetration (e.g., 2.4 GHz vs 5 GHz Wi-Fi)
 - `Luminous`: Emits light
 - Non-luminous objects do not emit light
 - `Colour`: Reflected parts of white light from non-luminous objects
 - Blacks absorb all visible light while whites do the opposite

### Luminescence
 - Things that emit light fill in here plz thanks

### Rays
 - Light path can be tracked via arrrows
 - `Normal`: Perpendicular line to an interface (e.g., mirror, medium boundary), intersecting where light reflects off
 - `Angle of incidence`: Angle of light hitting reflective surface, relative to the normal
 - `Angle of reflection`: Angle of light leaving reflective surface, relative to the normal
 - Laws of reflection
     - Angle of incidence = angle of reflection
     - Light rays are on the same plane
 - Types of reflection
     - `Specular reflection`: All normals are parallel (e.g., reflection off mirror)
     - `Diffuse reflection`: Not all normals are parallel (e.g., paper, not-mirrors)

## Mirrors
 - A mininum of **two** incident rays are required to find an image
 - Where rays converge describe image
 - **Dotted** lines are used for light going beyond a mirror (as light does not actually travel there)
 - `SALT`: Describes image
    - `Size`: Relative to object
    - `Attitude`: Orientation relative to object
    - `Location`: Relative to mirror and/or object
    - `Type`: Virtual (behind mirror) or real (in front of mirror)

### Plane mirrors

<img src="https://www.researchgate.net/profile/Merlin_John2/publication/293415482/figure/fig1/AS:326758030168064@1454916593825/Ray-diagram-for-image-formation-of-a-point-object.png" width="500">

 - `Object-image line`: Line perpendicular to plane mirror
    - Distance is equal on both sides of mirror
    - Describes location of object without requiring 2+ incident rays
    - Banned

### Concave and convex mirrors
 - `Concave mirror`: Curved mirror curving inwards in the direction of incident rays, like a cave
 - `Convex mirror`: Curved mirror curving away from incident rays, like back of a spoon

<img src="https://files.mtstatic.com/site_4539/4976/0?Expires=1576600636&Signature=RbdPtITqyUy5SmHpEqHj3m073CJZp3jNVvnB-1MPxZe9IoOZhT7bJepThEfKeCgaIldG9~5JrX-DmKqPBGlqzYDo03PM5NZCRcYd6NDEU-tjjIp2p7zurr7SkRHPCYRXBJduynGC1ivSS1LjS5lhDK4waXHtB-EMhChAAAzfp5E_&Key-Pair-Id=APKAJ5Y6AV4GI7A555NA" width="700">

 - `Principal axis`: $`PA`$, line perpendicular to mirror when it hits it
 - `Centre of curvature`: $`C`$, point where the centre of the circle would be if mirror was extended to a full circle
 - `Focus`: $`F`$, point where all light rays focus on if incident rays are parallel to principal axis
 - `Vertex`: $`V`$, point where principal axis meets mirror
 - Imaging rules for curved mirrors:
    - 1. Any incident ray **parallel** to the principal axis will reflect directly to or away from the **focus**
    - 2. Any incident ray that would pass through the **focus** will reflect **parallel** to the principal axis
    - 3. Any incident ray that would pass through the **centre** of curvature will reflect **back on the same path**
    - 4. Any incident ray that reflects off the **vertex** reflect as if it were a plane mirror

**Characteristics of concave mirror images**

| **Object location** | **Size** | **Attitude** | **Location** | **Type** |
| :--- | :--- | :--- | :--- | :--- |
| Farther than C | Smaller than object | Inverted | Between C and F | Real |
| At C | Same as object | Inverted | On C | Real |
| Between C and F | Larger than object | Inverted | Farther than C | Real |
| At F | N/A, lines do not converge | | | |
| Between F and V | Larger than object | Upright | Behind mirror | Virtual |

**Characteristics of convex mirror images**

| **Object location** | **Size** | **Attitude** | **Location** | **Type** |
| :--- | :--- | :--- | :--- | :--- |
| Anywhere | Smaller than object | Upright | Between F and V/behind mirror | Virtual | 

## Refraction
 - Speed of light depends on its medium
 - Light bending while transitioning from a slower to faster medium or vice versa
 - Greater the change in speed, greater than change in direction
 - Turns in direction of **leading edge**
    - Analogy: Sleds slowing from one runner first when transitioning from snow to pavement
 - **Slow -> fast** medium: Refracts **away** from normal
 - **Fast -> slow** medium: Refracts **towards** normal
 - `Angle of refraction`: Angle of light after interface, relative to normal
 - Index of refraction: speed of light in vacuum / speed of light in medium
    - $`n = \frac{c}{v}`$
 - $`n_{1}sin\theta_{incidence} = n_{2}sin\theta_{refraction}`$
    - Where $`n_{1}`$ and $`n_{2}`$ are the refractive indexes of two different media
 - Snell's law: $`\frac{sin\theta_{2}}{sin\theta_{1}} = \frac{v_{2}}{v_{1}} = \frac{n_{1}}{n_}2}

## Total internal reflection
 - `Critical angle`: Angle of incidence that causes refracted ray to be perpendicular to normal
 - TIR occurs when angle of incidence exceeds critical angle, causing near-100% reflection
 - Happens only when refracting from **slow to fast**
 - **Refraction is not perfect; some light is reflected during refraction**
    - Reflected ray grows brighter as we reach critical angle, and refracted ray grows dimmer
 - **Higher** index of refraction = **lower** critical angle

<img src="https://www.physicsclassroom.com/Class/refrn/u14l3b2.gif" width="500">